// index.js

// Self called function to start on file include
(() => {
	document.addEventListener('DOMContentLoaded', () => {
		updateGesa();
	});
})();

function updateGesa()
{
	$('#updateGesa').on('click', async () => {
		const dialog = $('#dialog-info');
		const dialogParams = {
			resizable: false,
			draggable: false,
			width: 800,
			minHeight: 204,
			open: async (e, ui) => {
				try {
					const data = await ajaxPromiseJSON({
						url: 'display.php',
						data: { action: 'updateGesa' },
					});

					$('.finish-msg .last_start', dialog).html(data.last_start);
					$('.finish-msg .last_end', dialog).html(data.last_end);
					$('.finish-msg .proc', dialog).html(data.log);
					$('.dialogContent', dialog).trigger('finished');
					setTimeout(() => {
						dialog.dialog('close');
					}, 4000);
				} catch (err) {
					displayUserMessage(err, [], 'dialog-messages');

					// Change progress bar complete on failed
					$('#progressbar', dialog).addClass('failed');
					$('#progressbar', dialog).progressbar('value', $('#progressbar').progressbar('option', 'max'));
					$('#progressbar .progress-label', dialog).text(globals.lang.ERR_CANNOT_UPDATE);
					$('.start-msg', dialog).hide();
				}
			},
			close: () => {
				location.reload();
			},
		};

		openDialogByAJAX('dialog.php', { action: 'updateGesa' }, globals.lang['UPDATE'], dialog, dialogParams, {}, false);
	});
}

// Get server url & port and set it on html
async function getServerAsync(gesaSN)
{
	let server = { url: '', port: '' };

	const urlItem = $('.serverUrl');
	const portItem = $('.serverPort');
	urlItem.css('cursor', 'wait');
	portItem.css('cursor', 'wait');

	try {
		const data = await ajaxPromiseJSON({
			url: 'display.php',
			data: { action: 'getGesaServerInfos', gesa_sn: gesaSN },
		});

		server.url = data?.url || '';
		server.port = data?.port || '';
	
		urlItem.html(server.url);
		portItem.html(server.port);
	} catch (err) {
		urlItem.html('/');
		portItem.html('/');
		displayUserMessage(err);
	} finally {
		urlItem.css('cursor', '');
		portItem.css('cursor', '');

		return server;
	}
}

// Get public ip and set it on html
async function getIpPubAsync()
{
	const htmlItem = $('.publicIp');
	htmlItem.css('cursor', 'wait');

	try {
		const ipPub = await ajaxPromiseJSON({
			url: 'display.php',
			data: { action: 'getGesaIpPub' },
		});
	
		htmlItem.html(ipPub);
	} catch (err) {
		htmlItem.html('/');
		displayUserMessage(err);
	} finally {
		htmlItem.css('cursor', '');
	}
}

// Get diag status DNS and set it on html
async function getDiagDNSAsync()
{
	// Init content for failling DNS request
	let content = {
		class: 'EventCritical',
		text: globals.lang.FAILED,
	};

	try {
		const isDNS = await ajaxPromiseJSON({
			url: 'display.php',
			data: { action: 'getGesaDiagDNS' },
		});

		if(isDNS)
		{
			// If DNS is true set content ok 
			content.class = 'EventOK';
			content.text = globals.lang.OK;
		}
	} catch (err) {
		displayUserMessage(err);
	} finally {
		const htmlItem = $('.diagDNS');
		// Remove progress bar
		$('.progressbar', htmlItem).progressbar('destroy');
		htmlItem.removeClass('progressBarTabCell');
		htmlItem.empty();
		// Set html content (OK or FAILED)
		htmlItem.addClass(content.class);
		htmlItem.html(content.text);
	}
}

// Get diag status web & server and set it on html
async function getDiagLinkAsync(server)
{
	// Init content for failling request
	let content = {
		web: {
			class: 'EventCritical',
			text: globals.lang.FAILED,
		},
		srv: {
			class: 'EventCritical',
			text: globals.lang.FAILED,
		},
		ecatp: {
			class: 'EventCritical',
			text: globals.lang.FAILED,
		},
	};

	try {
		const diag = await ajaxPromiseJSON({
			url: 'display.php',
			data: { action: 'getGesaDiagLink', server_url: server.url, port: server.port },
		});

		// If requests are true set content ok 
		if(diag.isWEB)
		{
			content.web.class = 'EventOK';
			content.web.text = globals.lang.OK;
		}
		if(diag.isSRV)
		{
			content.srv.class = 'EventOK';
			content.srv.text = globals.lang.OK;
		}
		if(diag.isECATP)
		{
			content.ecatp.class = 'EventOK';
			content.ecatp.text = globals.lang.OK;
		}
	} catch (err) {
		displayUserMessage(err);
	} finally {
		const webItem = $('.diagWEB');
		const srvItem = $('.diagSRV');
		const ecatpItem = $('.diagECATP');
		// Remove progress bar
		$('.progressbar', webItem).progressbar('destroy');
		webItem.removeClass('progressBarTabCell');
		webItem.empty();
		$('.progressbar', srvItem).progressbar('destroy');
		srvItem.removeClass('progressBarTabCell');
		srvItem.empty();
		$('.progressbar', ecatpItem).progressbar('destroy');
		ecatpItem.removeClass('progressBarTabCell');
		ecatpItem.empty();
		// Set html content (OK or FAILED)
		webItem.addClass(content.web.class);
		webItem.html(content.web.text);
		srvItem.addClass(content.srv.class);
		srvItem.html(content.srv.text);
		ecatpItem.addClass(content.ecatp.class);
		ecatpItem.html(content.ecatp.text);
	}
}

// Get all data which may take some time to retreive and set them on the page when each request is over
async function getGesaAsyncData(gesaSN)
{
	// Init all progress bars
	const progressWrapper = $('.diagProgress');
	progressWrapper.addClass('progressBarTabCell');
	setProgressBar($('.progressbar', progressWrapper));

	// Start all requests symultaneously
	const server = getServerAsync(gesaSN);
	getIpPubAsync();
	getDiagDNSAsync();
	getDiagLinkAsync(await server);
}
